<?php
/**
 *
 * @link              https://homescriptone.com
 * @since             1.0.0
 * @package           Display_Reusable_Blocks
 *
 * @wordpress-plugin
 * Plugin Name:       Reusable Blocks Manager
 * Plugin URI:        https://homescriptone.com/plugins/display-reusable-blocks
 * Description:       Manage easily the reusable blocks created using Gutemberg within WordPress pages, posts, products blocks and other block types.
 * Version:           1.0.0
 * Author:            HomeScript
 * Author URI:        https://homescriptone.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       display-reusable-blocks
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DISPLAY_REUSABLE_BLOCKS_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-display-reusable-blocks-activator.php
 */
function activate_display_reusable_blocks() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-display-reusable-blocks-activator.php';
	Display_Reusable_Blocks_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-display-reusable-blocks-deactivator.php
 */
function deactivate_display_reusable_blocks() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-display-reusable-blocks-deactivator.php';
	Display_Reusable_Blocks_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_display_reusable_blocks' );
register_deactivation_hook( __FILE__, 'deactivate_display_reusable_blocks' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-display-reusable-blocks.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_display_reusable_blocks() {

	$plugin = new Display_Reusable_Blocks();
	$plugin->run();

}
run_display_reusable_blocks();
